@@ -1,3 +1,12 @@
+# -*- coding: utf-8 -*-
+
+"""
+Inheritance Diagram
+-------------------
+
+.. inheritance-diagram:: kotti.sqla
+"""
+
 from pyramid.compat import json
 from pyramid.security import ALL_PERMISSIONS
 from pyramid.security import Allow
@@ -98,25 +107,28 @@ def _make_mutable_method_wrapper(wrapper_class, methodname, mutates):
 
 for wrapper_class in (MutationDict, MutationList):
     for methodname, mutates in (
-        ('__iter__', False),
-        ('__len__', False),
-        ('__eq__', False),
-        ('__add__', False),
-        ('__getitem__', False),
-        ('__getslice__', False),
-        ('__repr__', False),
-        ('get', False),
-        ('keys', False),
+            ('__iter__', False),
+            ('__len__', False),
+            ('__eq__', False),
+            ('__add__', False),
+            ('__getitem__', False),
+            ('__getslice__', False),
+            ('__repr__', False),
+            ('get', False),
+            ('keys', False),
 
-        ('__setitem__', True),
-        ('__delitem__', True),
-        ('__setslice__', True),
-        ('__delslice__', True),
-        ('append', True),
-        ('insert', True),
-        ('pop', True),
-        ('setdefault', True),
-        ):
+            ('__setitem__', True),
+            ('__delitem__', True),
+            ('__setslice__', True),
+            ('__delslice__', True),
+            ('append', True),
+            ('clear', True),
+            ('extend', True),
+            ('insert', True),
+            ('pop', True),
+            ('setdefault', True),
+            ('update', True),
+            ):
         setattr(
             wrapper_class, methodname,
             _make_mutable_method_wrapper(
@@ -126,7 +138,7 @@ for wrapper_class in (MutationDict, MutationList):
 
 class NestedMixin(object):
     __parent__ = None
-    
+
     def __init__(self, *args, **kwargs):
         self.__parent__ = kwargs.pop('__parent__', None)
         super(NestedMixin, self).__init__(*args, **kwargs)
@@ -148,6 +160,9 @@ class NestedMixin(object):
                 break
         return value
 
+    def __eq__(self, other):
+        return self._d == other
+
 
 class NestedMutationDict(NestedMixin, MutationDict):
     def setdefault(self, key, default):
